@@ -63,7 +63,15 @@ class BaseDBoard(object):
         :return: The board type name
         :rtype: str
         '''
-        return 'MB-'+cls.number
+        return f"MB-{cls.number}"+cls.number
+
+    @classmethod
+    def getCode(cls):
+        '''Returns the board type code
+        :return: The board type code
+        :rtype: str
+        '''
+        return f"mb{cls.number}"
 
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
@@ -244,7 +252,7 @@ class BaseDBoard(object):
         :param int passwd: *password* to connect to the board
         
         '''
-        if self.dapi.regs.scsr.bits.access.value != DApiAccessLevel.NO.value:
+        if self.dapi.regs.scsr.bits.access.value != DApiAccessLevel.NO.value: #@UndefinedVariable
             self.disconnect()
         self.dapi.cmd.connect(level,passwd) 
         try:
